Package 'AudioScatter'

Title: Audiogram Scattergrams
Description: Creates pre- and post- intervention scattergrams based on audiometric data. These scattergrams are formatted for publication in Otology & Neurotology and other otolaryngology journals. For more details and instructions on how to use this package, please reference Pan and Oghalai (2026) <doi: 10.1097/MAO.0000000000004693>. For further history on the development of scattergrams for reporting audiometric results in clinical trials, please see Gurgel et al (2012) <doi:10.1177/0194599812458401>, Oghalai and Jackler (2016) <doi:10.1177/0194599816638314>.
Authors: Dorothy W. Pan [aut, cre], John S. Oghalai [aut]
Maintainer: Dorothy W. Pan <[email protected]>
License: MIT + file LICENSE
Version: 1.1.1
Built: 2026-07-01 15:37:41 UTC
Source: https://github.com/cran/AudioScatter

Help Index


AudioData

Description

An example dataset containing the preop PTA, preop WRS, postop PTA, and postop WRS. You can load your own dataset containing the preop PTA, preop WRS, and potentially postop PTA and postop WRS. The variables are as follows:

Usage

data(AudioData)

Format

A data frame with rows and 4 columns

Details

  • PrePTA. preop pure tone average

  • PreWRS. preop word recognition score

  • PostPTA. postop pure tone average

  • PostWRS. postop word recognition score


CalcChange Calculate Change between Post and Pre PTA and WRS and put in appropriate column and row for scattergram.

Description

Post-treatment change in PTA and WRS Calculate change in PTA Calculate change in WRS create new columns relating the change in WRS to the correct column for the scattergram. create new columns relating the change in PTA to the correct row for the scattergram.

Usage

CalcChange(dTable)

Arguments

dTable

table loaded from csv file including PrePTA, PreWRS, and possibly PostPTA, PostWRS.

Value

new table with change in PTA and WRS and columns/rows they should go in for PostScattergram.


load dataset to dTable.

Description

load dataset to dTable.

Usage

dTable

Format

An object of class tbl_df (inherits from tbl, data.frame) with 58 rows and 4 columns.


Calculate the audiogram changes and write to new table dTablePost

Description

Calculate the audiogram changes and write to new table dTablePost

Usage

dTablePost

Format

An object of class tbl_df (inherits from tbl, data.frame) with 58 rows and 8 columns.


SavePostScatter

Description

SavePostScatter

Usage

SavePostScatter(dTablePost)

Arguments

dTablePost

table resulting from CalcChange with change in PTA and WRS, dPTA and dWRS, respectively, as well as the column and row dPTA and dWRS should go.

Value

png file of postop scattergram


SavePreScatter

Description

SavePreScatter

Usage

SavePreScatter(dTable)

Arguments

dTable

table loaded from csv file including PrePTA, PreWRS, and possibly PostPTA, PostWRS.

Value

png file for preop scattergram.